@@ -17,3 +17,6 @@ from antlr4_verilog.systemverilog.SystemVerilogLexer import SystemVerilogLexer
 from antlr4_verilog.systemverilog.SystemVerilogParser import SystemVerilogParser
 from antlr4_verilog.systemverilog.SystemVerilogParserListener import SystemVerilogParserListener
 from antlr4_verilog.systemverilog.SystemVerilogParserVisitor import SystemVerilogParserVisitor
+from antlr4_verilog.systemverilog.SystemVerilogPreParser import SystemVerilogPreParser
+from antlr4_verilog.systemverilog.SystemVerilogPreParserListener import SystemVerilogPreParserListener
+from antlr4_verilog.systemverilog.SystemVerilogPreParserVisitor import SystemVerilogPreParserVisitor
