@@ -17,6 +17,6 @@ from antlr4_verilog.verilog.VerilogLexer import VerilogLexer
 from antlr4_verilog.verilog.VerilogParser import VerilogParser
 from antlr4_verilog.verilog.VerilogParserListener import VerilogParserListener
 from antlr4_verilog.verilog.VerilogParserVisitor import VerilogParserVisitor
-from antlr4_verilog.verilog.VerilogPreprocessorParser import VerilogPreprocessorParser
-from antlr4_verilog.verilog.VerilogPreprocessorParserListener import VerilogPreprocessorParserListener
-from antlr4_verilog.verilog.VerilogPreprocessorParserVisitor import VerilogPreprocessorParserVisitor
+from antlr4_verilog.verilog.VerilogPreParser import VerilogPreParser
+from antlr4_verilog.verilog.VerilogPreParserListener import VerilogPreParserListener
+from antlr4_verilog.verilog.VerilogPreParserVisitor import VerilogPreParserVisitor
